# Airfoil Optimizer

by Peter Sharpe

## WARNING

Airfoil optimization is dangerous territory that is so ripe for misunderstanding - it's much more complicated and nuanced than the point-design-drag-minimization problem that it appears to be on the surface. Before you continue, please read and deeply understand these articles:

1. What you should and shouldn't do when optimizing airfoils: [Mark Drela, Pros and Cons of Airfoil Optimization](https://www.researchgate.net/publication/265279078_Pros_Cons_of_Airfoil_Optimization)
2. Comparisons of airfoil geometry parameterization techniques (there are many good papers on this topic, but I like this one): [D. A. Masters, "Geometric Comparison of Aerofoil Shape Parameterization Methods", AIAA Journal, 2017.](https://arc.aiaa.org/doi/pdf/10.2514/1.J054943)
3. The seminal paper on the CST (Kulfan) parameterization technique: [Brenda Kulfan, "Universal Parametric Geometry Representation Method"](http://mx1.brendakulfan.com/docs/CST6.pdf)

